summaryrefslogtreecommitdiffstats
path: root/chrome/test/testing_profile.h
diff options
context:
space:
mode:
authorpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-02 21:40:00 +0000
committerpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-02 21:40:00 +0000
commitd486a085bd85065f8952d43f20e3f2c622ef7b7a (patch)
tree6b56ee8893dd1660a3c2ed7a2ecb8a5c8d948441 /chrome/test/testing_profile.h
parent740847d37d057d41ea5956ec0cb123a7dbd5b904 (diff)
downloadchromium_src-d486a085bd85065f8952d43f20e3f2c622ef7b7a.zip
chromium_src-d486a085bd85065f8952d43f20e3f2c622ef7b7a.tar.gz
chromium_src-d486a085bd85065f8952d43f20e3f2c622ef7b7a.tar.bz2
Unittest for fix to allow navigation when there is no history DB.
BUG=25822 TEST=none Review URL: http://codereview.chromium.org/343067 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@30744 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/test/testing_profile.h')
-rw-r--r--chrome/test/testing_profile.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/chrome/test/testing_profile.h b/chrome/test/testing_profile.h
index 61083af..1a415d5 100644
--- a/chrome/test/testing_profile.h
+++ b/chrome/test/testing_profile.h
@@ -32,9 +32,11 @@ class TestingProfile : public Profile {
// Creates the history service. If |delete_file| is true, the history file is
// deleted first, then the HistoryService is created. As TestingProfile
- // deletes the directory containing the files used by HistoryService, the
- // boolean only matters if you're recreating the HistoryService.
- void CreateHistoryService(bool delete_file);
+ // deletes the directory containing the files used by HistoryService, this
+ // only matters if you're recreating the HistoryService. If |no_db| is true,
+ // the history backend will fail to initialize its database; this is useful
+ // for testing error conditions.
+ void CreateHistoryService(bool delete_file, bool no_db);
// Creates the BookmkarBarModel. If not invoked the bookmark bar model is
// NULL. If |delete_file| is true, the bookmarks file is deleted first, then